@@ -11,7 +11,6 @@ This module contains generic functions for use in other modules
 """
 
 from abc import abstractmethod
-from collections import namedtuple
 from functools import update_wrapper, wraps
 from inspect import isclass
 import logging
@@ -45,7 +44,6 @@ OPERATORS = {'=': _operator.eq,
              '>=': _operator.ge}
 
 
-Result = namedtuple('Result', ('valid', 'message', 'errorcode'))
 NoneType = type(None)
 
 if sys.version_info[0] < 3:  # pragma: no branch
@@ -54,19 +52,23 @@ else:
     BASESTRING = str
 
 
+def raise_with_traceback(exc, tback):  # pragma: no cover
+    """
+    Placeholder for version-specific implementation
+    """
+    raise NotImplementedError
+
+
 # Attempt to make a Python 2/3 compatible way to raise with a traceback
 # pylint: disable=exec-used
 if sys.version_info[0] < 3:  # pragma: no branch
     exec("""def raise_with_traceback(exc, tback):  # pragma: no cover
     raise exc.__class__, exc, tback
 """)
-# pylint: enable=exec-used
 else:
-    def raise_with_traceback(exc, tback):
-        """
-        Python 3 compatible raise statement
-        """
-        raise exc.with_traceback(tback)
+    exec("""def raise_with_traceback(exc, tback):
+    raise exc.with_traceback(tback) from None
+""")
 
 
 class ClassProperty(object):
